<?php

// setup theme
if (!function_exists('ssinfinity_setup')):
	function ssinfinity_setup() {
		add_theme_support('automatic-feed-links');
		add_theme_support('title-tag');
		add_theme_support('post-thumbnails');
		add_theme_support('custom-logo');
		add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
  	add_editor_style(get_template_directory_uri() . '/assets/css/editor.css');
		register_nav_menus(array(
			'primary' => esc_html__('Primary', 'ss-infinity'),
			'footer' => esc_html__('Footer', 'ss-infinity'),
		));
		if (!isset($content_width)) $content_width = 700;
	}
endif;
add_action('after_setup_theme', 'ssinfinity_setup');

// load css / js
function ssinfinity_enqueue() {
    wp_enqueue_style('ss-infinity-style', get_stylesheet_uri());
		wp_enqueue_style('ss-infinity-fonts', 'http://fonts.googleapis.com/css?family=Nunito:400,400i,700,700i', false);
    wp_enqueue_script('ss-infinity-script', get_template_directory_uri() . '/assets/js/script.js', array('jquery'), '1.0.0', true);
		if (is_singular() && comments_open() && get_option('thread_comments')) {
			wp_enqueue_script('comment-reply');
		}
}
add_action('wp_enqueue_scripts', 'ssinfinity_enqueue');

// appearance customizer
function ssinfinity_customize_register($wp_customize) {
	// background color
	$wp_customize->add_setting('ssinfinity_color_bg', array(
    'default' => '#0277BD',
    'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'ssinfinity_color_bg', array(
		'label' => esc_html__('Background', 'ss-infinity'),
		'section' => 'colors',
		'settings' => 'ssinfinity_color_bg',
	)));
	// text color
	$wp_customize->add_setting('ssinfinity_color_text', array(
    'default' => '#fff',
    'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'ssinfinity_color_text', array(
		'label' => esc_html__('Text Color', 'ss-infinity'),
		'section' => 'colors',
		'settings' => 'ssinfinity_color_text',
	)));
	// links / branding
	$wp_customize->add_setting('ssinfinity_color_links', array(
    'default' => '#ffffff',
    'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'ssinfinity_color_links', array(
		'label' => esc_html__('Links / Branding', 'ss-infinity'),
		'section' => 'colors',
		'settings' => 'ssinfinity_color_links',
	)));
	// sticky posts
	$wp_customize->add_setting('ssinfinity_color_sticky_bg', array(
    'default' => '#01579B',
    'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'ssinfinity_color_sticky_bg', array(
		'label' => esc_html__('Sticky Background', 'ss-infinity'),
		'section' => 'colors',
		'settings' => 'ssinfinity_color_sticky_bg',
	)));

}
add_action('customize_register', 'ssinfinity_customize_register');

// output customizer settings
function ssinfinity_customize_css() {
	echo '<style type="text/css">';
	echo 'body, .teaser-title span, #header-menu.active, #hamburger-inner, #hamburger-inner::before, #hamburger-inner::after {background-color:'. esc_html(get_theme_mod('ssinfinity_color_bg', '#0277BD')) .'; }';
	echo '.teaser a, #header-menu ul li a, #header-name, #header-desc, #footer .menu a, #footer-meta a, #footer-meta {color:'. esc_html(get_theme_mod('ssinfinity_color_links', '#ffffff')) .'; }';
	echo '#hamburger {color:'. esc_html(get_theme_mod('ssinfinity_color_links', '#ffffff')) .'; }';
	echo '.sticky, .sticky .teaser-title span, input[type=submit] {background-color:' . esc_html(get_theme_mod('ssinfinity_color_sticky_bg', '#01579B')) . '; }';
	echo 'body, .teaser-excerpt p, .teaser a, .sticky .teaser-excerpt p, #comments a, #respond a, .widget a {color:' . esc_html(get_theme_mod('ssinfinity_color_text', '#ffffff')) . '; }';
	echo '.teaser:before {background-color:' . esc_html(get_theme_mod('ssinfinity_color_text', '#ffffff')) . '; }';
	echo '</style>';
}
add_action('wp_head', 'ssinfinity_customize_css');

// footer widget area
function ssinfinity_widgets_init() {
	register_sidebar(array(
		'name' => esc_html__('Footer', 'ss-infinity'),
		'id' => 'footer',
		'before_widget' => '<div class="widget">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	));
}
add_action('widgets_init', 'ssinfinity_widgets_init');


?>
